@@ -44,6 +44,8 @@ describe 'designate::keystone::authtoken' do
         is_expected.to contain_designate_config('keystone_authtoken/token_cache_time').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_designate_config('keystone_authtoken/service_token_roles').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_designate_config('keystone_authtoken/service_token_roles_required').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_designate_config('keystone_authtoken/service_type').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_designate_config('keystone_authtoken/interface').with_value('<SERVICE DEFAULT>')
       end
     end
 
@@ -84,6 +86,8 @@ describe 'designate::keystone::authtoken' do
           :token_cache_time                     => '301',
           :service_token_roles                  => ['admin', 'service'],
           :service_token_roles_required         => false,
+          :service_type                         => 'identity',
+          :interface                            => 'internal',
         })
       end
 
@@ -121,6 +125,8 @@ describe 'designate::keystone::authtoken' do
         is_expected.to contain_designate_config('keystone_authtoken/token_cache_time').with_value(params[:token_cache_time])
         is_expected.to contain_designate_config('keystone_authtoken/service_token_roles').with_value(params[:service_token_roles])
         is_expected.to contain_designate_config('keystone_authtoken/service_token_roles_required').with_value(params[:service_token_roles_required])
+        is_expected.to contain_designate_config('keystone_authtoken/service_type').with_value(params[:service_type])
+        is_expected.to contain_designate_config('keystone_authtoken/interface').with_value(params[:interface])
       end
 
       it 'installs python memcache package' do
